# Example Package

This is a simple example package.

You can read more [here.](https://packaging.python.org/en/latest/tutorials/packaging-projects/)

pypi: [pypi/AppleBoiy](https://pypi.org/manage/project/apeboiy/releases/)
